@@ -21,7 +21,7 @@
 #' \dontrun{
 #' # To unzip and merge files downloaded from the NEON Data Portal
 #' stackByTable("~/NEON_par.zip")
-#' 
+#'
 #' # To unzip and merge files downloaded using zipsByProduct()
 #' stackByTable("~/filesToStack00024")
 #' }
@@ -51,7 +51,7 @@ stackByTable <- function(filepath, savepath=NA, folder=FALSE, saveUnzippedFiles=
   } else {
     folder <- TRUE
   }
-  
+
   #### Check whether data should be stacked ####
   if(folder==FALSE){
     files <- listFilesInZip(filepath)
@@ -60,36 +60,38 @@ stackByTable <- function(filepath, savepath=NA, folder=FALSE, saveUnzippedFiles=
       stop("Data files are not present in specified filepath.")
     }
   }
-  
+
   if(folder==TRUE){
     files <- list.files(filepath, pattern = "NEON.D[[:digit:]]{2}.[[:alpha:]]{4}.")
     if(length(files) == 0){
       stop("Data files are not present in specified filepath.")
     }
   }
-  
+
   dpID <- substr(basename(files[1]), 15, 27)
   package <- substr(files[1], nchar(files[1])-25, nchar(files[1])-21)
   if(package == "anded"){package <- "expanded"}
-  
+
   # error message if dpID isn't formatted as expected
   if(regexpr("DP[1-4]{1}.[0-9]{5}.001",dpID)!=1) {
     stop(paste(dpID, "is not a properly formatted data product ID. The correct format is DP#.#####.001, where the first placeholder must be between 1 and 4.", sep=" "))
   }
-  
-  if(substr(dpID, 5, 5) == "3"){
+
+  # error message for AOP data
+  if(substr(dpID, 5, 5) == "3" & dpID!="DP1.30012.001"){
     stop("This is an AOP data product, files cannot be stacked. Use byFileAOP() or byTileAOP() if you would like to download data.")
   }
-  
+
+  # error message for SAE data
   if(dpID == "DP4.00200.001"){
     stop("This eddy covariance data product is in HDF5 format and cannot be stacked.")
   }
-  
+
   if(dpID == "DP1.10017.001" && package != 'basic'){
     saveUnzippedFiles = TRUE
     writeLines("Note: Digital hemispheric photos (in NEF format) cannot be stacked; only the CSV metadata files will be stacked.")
   }
-  
+
   #### If all checks pass, unzip and stack files ####
   envt <- 0
   if(folder==FALSE) {
@@ -98,19 +100,18 @@ stackByTable <- function(filepath, savepath=NA, folder=FALSE, saveUnzippedFiles=
       savepath <- file.path(tempdir(), paste("store", format(Sys.time(), "%Y%m%d%H%M%S"), sep=""))
       envt <- 1
     }
-    orig <- list.files(savepath)
     if(length(grep(files, pattern = ".zip")) > 0){
-      unzipZipfileParallel(zippath = filepath, outpath = savepath, level = "all", nCores)
+      zipList <- unzipZipfileParallel(zippath = filepath, outpath = savepath, level = "all", nCores)
     }
   }
-  
+
   if(folder==TRUE) {
     if(is.na(savepath)){savepath <- filepath}
     if(savepath=="envt") {
       savepath <- file.path(tempdir(), paste("store", format(Sys.time(), "%Y%m%d%H%M%S"), sep=""))
       envt <- 1
     }
-    orig <- list.files(savepath)
+    zipList <- files
     if(length(grep(files, pattern = ".zip")) > 0){
       unzipZipfileParallel(zippath = filepath, outpath = savepath, level = "in", nCores)
     } else {
@@ -121,15 +122,22 @@ stackByTable <- function(filepath, savepath=NA, folder=FALSE, saveUnzippedFiles=
         }
       }
     }
-  } 
+  }
 
   stackDataFilesParallel(savepath, nCores, dpID)
   getReadmePublicationDate(savepath, out_filepath = paste(savepath, "stackedFiles", sep="/"), dpID)
-  
-  if(saveUnzippedFiles == FALSE){cleanUp(savepath, orig)}
-  
+
+  if(saveUnzippedFiles == FALSE){
+    zipList <- zipList %>%
+      unlist() %>%
+      basename() %>%
+      gsub('.zip', '', .)
+
+    cleanUp(savepath, zipList)
+    }
+
   if(envt==1) {
-    
+
     stacked_files <- list.files(paste(savepath, "stackedFiles", sep="/"), full.names = TRUE)
     v <- utils::read.csv(stacked_files[grep('variables', stacked_files)], header=T, stringsAsFactors=F)
 
@@ -138,7 +146,8 @@ stackByTable <- function(filepath, savepath=NA, folder=FALSE, saveUnzippedFiles=
         fls <- suppressWarnings(data.table::fread(x, sep=',', keepLeadingZeros = TRUE, colClasses = list(character = c('HOR.VER'))))
       } else if(length(grep("readme", basename(x)))>0) {
         fls <- suppressMessages(readr::read_table(x, col_names = FALSE))
-        } else if(length(grep("variables", basename(x)))>0 | length(grep("validation", basename(x)))>0) {
+        } else if(length(grep("variables", basename(x)))>0 | length(grep("validation", basename(x)))>0 | 
+                  length(grep("categoricalCodes", basename(x)))>0) {
           fls <- suppressWarnings(data.table::fread(x, sep=','))
         } else {
           fls <- try(readTableNEON(x, v), silent=T)
